import Tests.MonadicTests (monadicTests)

import System.Exit
import Test.HUnit

allTests = TestList
  [ "Monadic API" ~: monadicTests
  ]

main = do
  result <- runTestTT allTests
  if (errors result + failures result) > 0
    then exitFailure
    else exitSuccess

